<?php
/**
 * Plugin Name:       Car Dealer - Geo Fencing
 * Plugin URI:        http://www.potenzaglobalsolutions.com/
 * Description:       This plugin contains Geo Fencing functionality for the "Car Dealer" theme.
 * Version:           1.0.0
 * Author:            Potenza Global Solutions
 * Author URI:        http://www.potenzaglobalsolutions.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       cardealer-geo-fencing
 *
 * @package cardealer-geo-fencing
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

if ( ! defined( 'CDGF_PATH' ) ) {
	define( 'CDGF_PATH', plugin_dir_path( __FILE__ ) );
}
if ( ! defined( 'CDGF_URL' ) ) {
	define( 'CDGF_URL', plugin_dir_url( __FILE__ ) );
}

if ( ! defined( 'CDGF_VERSION' ) ) {
	define( 'CDGF_VERSION', '1.0.0' );
}

// Plugin activation/deactivation hooks.
register_activation_hook( __FILE__, 'cdgf_activate' );

if ( ! function_exists( 'cdgf_activate' ) ) {
	/**
	 * The code that runs during plugin activation.
	 */
	function cdgf_activate() {
		// Display admin notice if Visual Composer is not activated.
		add_action( 'admin_notices', 'cdgf_is_vc_active' );
		add_action( 'admin_notices', 'cdgf_plugin_active_notices' );

		/**
		 * Add custom table when plugin active for geo fencing.
		 */
		global $wpdb;
		$table_name = $wpdb->prefix . 'geo_fencing';
		if ( $wpdb->get_var( $wpdb->prepare( 'SHOW TABLES LIKE %s', $table_name ) ) !== $table_name ) {
			// Table not in database. Create new table.
			$charset_collate = $wpdb->get_charset_collate();
			$sql             = "CREATE TABLE $table_name (
					id INT NOT NULL AUTO_INCREMENT PRIMARY KEY ,
					post_id INT NOT NULL ,
					radius DOUBLE NOT NULL ,
					lat DOUBLE NOT NULL ,
					lng DOUBLE NOT NULL
				) $charset_collate ENGINE = MYISAM";
			require_once ABSPATH . 'wp-admin/includes/upgrade.php';
			dbDelta( $sql );
		}
	}
}

add_action( 'admin_enqueue_scripts', 'cdgf_admin_enqueue_scripts' );
if ( ! function_exists( 'cdgf_admin_enqueue_scripts' ) ) {
	/**
	 * Add script and style in wp-admin side
	 *
	 */
	function cdgf_admin_enqueue_scripts() {
		// phpcs:disable WordPress.Security.NonceVerification.Recommended
		$google_key = ( function_exists( 'cardealer_get_google_maps_api_key' ) ) ? cardealer_get_google_maps_api_key() : '';
		wp_register_script( 'cdgf-google-maps-apis', 'https://maps.googleapis.com/maps/api/js?key=' . $google_key . '&libraries=drawing,places&callback=geoFenc', array(), CDGF_VERSION, true );
		wp_register_script( 'cdgf-geofance-map', trailingslashit( CDGF_URL ) . 'js/cd-geofance-map.js', array(), CDGF_VERSION, true );
	}
}

add_action( 'wp_enqueue_scripts', 'cdgf_load_style_script' );
if ( ! function_exists( 'cdgf_load_style_script' ) ) {
	/**
	 * Add script and style in wp-admin side
	 */
	function cdgf_load_style_script() {

		// CSS.
		wp_enqueue_style( 'cdgf-css-geofance', trailingslashit( CDGF_URL ) . 'css/cd-geofance.css', array(), CDGF_VERSION );
		wp_register_script( 'cdgf-geofance', trailingslashit( CDGF_URL ) . 'js/cd-geofance.js', array(), CDGF_VERSION, true );

		$cars_geo_fencing = cdgf_get_geo_count();
		// Add message for pdf brochare.
		wp_localize_script(
			'cdgf-geofance',
			'cdgf_obj',
			array(
				'ajaxurl'  => admin_url( 'admin-ajax.php' ),
				'geofenc'  => $cars_geo_fencing,
			)
		);
		wp_enqueue_script( 'cdgf-geofance' );
	}
}

require_once trailingslashit(CDGF_PATH) . 'inc/cpts/geo-fencing.php'; // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound

/**
 * Function to add Geo Fencing button in cardealer panel.
 *
 * @param array $features features.
 */
function cdgf_extend_cardealer_other_fetures( $features ) {

	$features['geo-fencing'] = array(
		'title' => esc_html__( 'Geo Fencing', 'cardealer-geo-fencing' ),
		'link'  => admin_url( 'edit.php?post_type=cars_geofencing' ),
		'desc'  => esc_html__( 'Click this button to open Geo Fencing section.', 'cardealer-geo-fencing' ),
	);

	return $features;
}
add_filter( 'cardealer_other_fetures', 'cdgf_extend_cardealer_other_fetures' );

function cdgf_theme_options( $opt_name ) {
	/*Dealer Cars Geo Fencing Settings options */
	Redux::setSection(
		$opt_name,
		array(
			'title'            => esc_html__( 'Geo Fencing Settings', 'cardealer-geo-fencing' ),
			'id'               => 'geo-fencing-settings',
			'subsection'       => true,
			'customizer_width' => '400px',
			'icon'             => 'fas fa-chevron-right',
			'fields'           => array(
				array(
					'id'      => 'cars-geo-fencing',
					'type'    => 'button_set',
					'title'   => esc_html__( 'Enable Geo Fencing', 'cardealer-geo-fencing' ),
					'desc'    => esc_html__( 'Enable / Disable Geo Fencing on front side.', 'cardealer-geo-fencing' ),
					'options' => array(
						'1' => esc_html__( 'Yes', 'cardealer-geo-fencing' ),
						'0' => esc_html__( 'No', 'cardealer-geo-fencing' ),
					),
					'default' => '1',
				),
				array(
					'id'          => 'geo_fencing_background_color',
					'type'        => 'color',
					'title'       => esc_html__( 'Geo Fencing Background Color', 'cardealer-geo-fencing' ),
					'desc'        => esc_html__( 'Geo Fencing Section Background Color in Top.', 'cardealer-geo-fencing' ),
					'transparent' => false,
					'default'     => '#db2d2e',
					'validate'    => 'color',
					'mode'        => 'background',
					'required'    => array( 'cars-geo-fencing', '=', '1' ),
				),
			),
		)
	);
}
add_action( 'car_dealer_options_after_vehicle_settings', 'cdgf_theme_options' );
